<?php
namespace Bushelpowered\Api\Fulfillment\Ticket\V1;

use \Bushelpowered\Api\Fulfillment\Ticket\V1\Request\GetAllTicketsRequest;
use \Bushelpowered\Api\Fulfillment\Ticket\V1\Response\TicketListResponse;
use \Bushelpowered\Api\Common\BadRequest;
use \Bushelpowered\Api\Common\NotAuthenticated;
use \Bushelpowered\Api\Common\NotAuthorized;
use \Bidl\Php\Core\Builtins\UnknownError;

class GetAllTickets 
{
    public function __construct(public \Bidl\Php\Core\BidlClient $client)
    {
    }
    
    public function call(GetAllTicketsRequest $request, $headers): TicketListResponse | BadRequest | NotAuthenticated | NotAuthorized | UnknownError
    {
         return $this->client->call('api/fulfillment/ticket/v1/GetAllTickets', $request, $this->getWrapper(), $headers);
    }
    
    private function getWrapper() {
        return new class () implements \Bidl\Php\Core\BidlResponse {

            /** @var TicketListResponse | BadRequest | NotAuthenticated | NotAuthorized | UnknownError */
            public $response;
        
            public function __construct()
            {
                $this->mapper = new \JsonMapper();
            }
            
            public function fromJson($data) 
            {
                switch($data->type) {
                  case 'api.fulfillment.ticket.v1#GetAllTicketsSuccess':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Fulfillment\Ticket\V1\Response\TicketListResponse::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#BadRequest':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\BadRequest::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotAuthenticated':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthenticated::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotAuthorized':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthorized::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                   default: 
                     $this->response = new \Bidl\Php\Core\Builtins\UnknownError('The response was not a valid bidl response.');
                }
            }
        };
    }
}