<?php
namespace Bushelpowered\Api\Platform\Tenant\V1;

use \Bushelpowered\Api\Platform\Tenant\V1\Request\GetOrUpsertTenantsRequest;
use \Bushelpowered\Api\Platform\Tenant\V1\Response\TenantListResponse;
use \Bushelpowered\Api\Common\BadRequest;
use \Bushelpowered\Api\Common\ConstraintViolation;
use \Bushelpowered\Api\Common\NotAuthenticated;
use \Bushelpowered\Api\Common\NotAuthorized;
use \Bidl\Php\Core\Builtins\UnknownError;

class GetOrUpsertTenants 
{
    public function __construct(public \Bidl\Php\Core\BidlClient $client)
    {
    }
    
    public function call(GetOrUpsertTenantsRequest $request, $headers): TenantListResponse | BadRequest | ConstraintViolation | NotAuthenticated | NotAuthorized | UnknownError
    {
         return $this->client->call('api/platform/tenant/v1/GetOrUpsertTenants', $request, $this->getWrapper(), $headers);
    }
    
    private function getWrapper() {
        return new class () implements \Bidl\Php\Core\BidlResponse {

            /** @var TenantListResponse | BadRequest | ConstraintViolation | NotAuthenticated | NotAuthorized | UnknownError */
            public $response;
        
            public function __construct()
            {
                $this->mapper = new \JsonMapper();
            }
            
            public function fromJson($data) 
            {
                switch($data->type) {
                  case 'api.platform.tenant.v1#GetOrUpsertTenantsSuccess':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Platform\Tenant\V1\Response\TenantListResponse::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#BadRequest':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\BadRequest::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#ConstraintViolation':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\ConstraintViolation::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotAuthenticated':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthenticated::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotAuthorized':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthorized::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                   default: 
                     $this->response = new \Bidl\Php\Core\Builtins\UnknownError('The response was not a valid bidl response.');
                }
            }
        };
    }
}